import unittest

from .networkUtil import *


class TestNetworkUtil(unittest.TestCase):

    def test_1(self):
        data = 网页_取外网IP()
        print(data)

    def test_2(self):
        data = 网页_访问("https://www.125.la/")
        print(data.字节集.decode('utf-8'))

    def test_3(self):
        data = 网页_访问("https://www.baidu.com/")
        print(data.字节集.decode('utf-8'))
