"""
兼容原生wx模块直接插上易函数的翅膀

"""
from .component.__init__ import *


class AnimationCtrl( 动画框 , 公用方法):
    pass


class BitmapButton( 图形按钮 , 公用方法):
    pass


class Button( 按钮 , 公用方法):
    pass


class CalendarCtrl(日历框  , 公用方法):
    pass


class CheckBox( 复选框 , 公用方法):
    pass


class CheckListBox( 选择列表框 , 公用方法):
    pass


class ColourPickerCtrl( 颜色选择器 , 公用方法):
    pass


class ComboBox( 组合框 , 公用方法):
    pass


class CommandLinkButton( 引导按钮 , 公用方法):
    pass


class DatePickerCtrl( 日期框 , 公用方法):
    pass


class EditableListBox( 排序列表框 , 公用方法):
    pass


class FloatSpin(  小数微调框, 公用方法):
    pass


class Frame( 窗口 , 公用方法):
    pass


class Gauge( 进度条 , 公用方法):
    pass


class GradientButton( 图文按钮L , 公用方法):
    pass


class HyperlinkCtrl( 超级链接框 , 公用方法):
    pass


class ListBox( 列表框 , 公用方法):
    pass


class ListCtrl( 超级列表框 , 公用方法):
    pass


class RadioBox( 分组单选框 , 公用方法):
    pass


class RadioButton( 单选框 , 公用方法):
    pass


class ScrollBar( 滚动条 , 公用方法):
    pass


class Slider( 滑块条 , 公用方法):
    pass


class SpinCtrl( 整数微调框 , 公用方法):
    pass


class StaticBitmap( 图片框 , 公用方法):
    pass


class StaticText( 标签 , 公用方法):
    pass


class TextCtrl( 编辑框 , 公用方法):
    pass


class ThemedGenBitmapTextButton( 图文按钮 , 公用方法):
    pass


class TimePickerCtrl( 时间框 , 公用方法):
    pass


class Panel( 容器 , 公用方法):
    pass

class Timer( 时钟 , 公用方法):
    pass


class Image( 图片操作 , 公用方法):
    pass

